No changes in refcount semantics -- key init is false; replace

static_key_slow_inc|dec   with   static_branch_inc|dec
static_key_false          with   static_branch_unlikely

Added a '_key' suffix to i2c_trace_msg, for better self
documentation.

Cc: Wolfram Sang <w...@the-dreams.de>
Cc: linux-...@vger.kernel.org
Signed-off-by: Davidlohr Bueso <dbu...@suse.de>
---
 drivers/i2c/i2c-core-base.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/i2c/i2c-core-base.c b/drivers/i2c/i2c-core-base.c
index 16a3b73375a6..c8461fb26c0d 100644
--- a/drivers/i2c/i2c-core-base.c
+++ b/drivers/i2c/i2c-core-base.c
@@ -69,18 +69,18 @@ static DEFINE_IDR(i2c_adapter_idr);
 
 static int i2c_detect(struct i2c_adapter *adapter, struct i2c_driver *driver);
 
-static struct static_key i2c_trace_msg = STATIC_KEY_INIT_FALSE;
+DEFINE_STATIC_KEY_FALSE(i2c_trace_msg_key);
 static bool is_registered;
 
 int i2c_transfer_trace_reg(void)
 {
-       static_key_slow_inc(&i2c_trace_msg);
+       static_branch_inc(&i2c_trace_msg_key);
        return 0;
 }
 
 void i2c_transfer_trace_unreg(void)
 {
-       static_key_slow_dec(&i2c_trace_msg);
+       static_branch_dec(&i2c_trace_msg_key);
 }
 
 const struct i2c_device_id *i2c_match_id(const struct i2c_device_id *id,
@@ -1848,11 +1848,11 @@ int __i2c_transfer(struct i2c_adapter *adap, struct 
i2c_msg *msgs, int num)
        if (adap->quirks && i2c_check_for_quirks(adap, msgs, num))
                return -EOPNOTSUPP;
 
        /* i2c_trace_msg gets enabled when tracepoint i2c_transfer gets
         * enabled.  This is an efficient way of keeping the for-loop from
         * being executed when not needed.
         */
-       if (static_key_false(&i2c_trace_msg)) {
+       if (static_branch_unlikely(&i2c_trace_msg_key)) {
                int i;
                for (i = 0; i < num; i++)
                        if (msgs[i].flags & I2C_M_RD)
@@ -1871,7 +1871,7 @@ int __i2c_transfer(struct i2c_adapter *adap, struct 
i2c_msg *msgs, int num)
                        break;
        }
 
-       if (static_key_false(&i2c_trace_msg)) {
+       if (static_branch_unlikely(&i2c_trace_msg_key)) {
                int i;
                for (i = 0; i < ret; i++)
                        if (msgs[i].flags & I2C_M_RD)
@@ -1848,11 +1848,11 @@ int __i2c_transfer(struct i2c_adapter *adap, struct 
                return -EOPNOTSUPP;
 
-       /* i2c_trace_msg gets enabled when tracepoint i2c_transfer gets
+       /* i2c_trace_msg_key gets enabled when tracepoint i2c_transfer gets
         * enabled.  This is an efficient way of keeping the for-loop from
         * being executed when not needed.
-- 
2.13.6

Reply via email to